.. _spkg_decorator:

decorator: Python library providing decorators
========================================================

Description
-----------

Better living through Python with decorators

Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    5.1.1

version_requirements.txt::

    decorator >=4.4.0


Equivalent System Packages
--------------------------

.. tab:: Arch Linux

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-decorator 


.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install decorator 


.. tab:: Debian/Ubuntu

   .. CODE-BLOCK:: bash

       $ sudo apt-get install python3-decorator 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo yum install python3-decorator 


.. tab:: Gentoo Linux

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/decorator 


.. tab:: MacPorts

   .. CODE-BLOCK:: bash

       $ sudo port install py-decorator 


.. tab:: openSUSE

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3\$\{PYTHON_MINOR\}-decorator 


.. tab:: Void Linux

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-decorator 



See https://repology.org/project/python:decorator/versions

If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure``
will check if the system package can be used.

